# todo use interger_to_roman to convert the number to roman numerals
ROMANS = ['I', 'II', 'III', 'IV', 'V', 'VI', 'VII',
          'VIII', 'IX', 'X', 'XI', 'XII', 'XIII',
          'XIV', 'XV', 'XVI', 'XVII', 'XVIII', 'XIX',
          'XX', 'XXI', 'XXII', 'XXIII', 'XXIV', 'XXV',
          'XXVI', 'XXVII', 'XXVIII', ]

# TODO: these might not be accurate
LENT_MASSES = ('Sicut oculi', 'Domine refugium', 'Reminíscere', 'Confessio',
               'De necessitatibus', 'Intret oratio', 'Redime me', 'Tibi dixit',
               'Ne derelinquas me', 'Deus, in adjutorium', 'Ego autem',
               'Lex Domini', 'In Deo laudabo', 'Ego clamavi', 'Ego autem',
               'Salus populi', 'Fac mecum', 'Verba mea', 'Deus, in nomine',
               'Exaudi, Deus', 'Cum sanctificatus', 'Lætetur cor', 'Meditatio',
               'Sitientes', 'Miserere mihi', 'Expecta Dominum',
               'Liberator meus', 'Omnia, quæ fecisti', 'Miserere mihi',
               'Miserere mihi',)

# beginning with the fourth Sunday after Pentecost
# TODO: double check the last ones...
PENTECOST_MASSES = ('Dominus illuminatio', 'Exaudi, Domine',
                    'Dominus fortitudo', 'Omnes gentes', 'Suscepimus',
                    'Ecce Deus', 'Cum clamarem', 'Deus in loco',
                    'Deus in adjutorium', 'Respice Domine', 'Protector noster',
                    'Inclina Domine', 'Miserere mihi', 'Justus es', 'Da pacem',
                    'Salus populi', 'Omnia', 'In voluntate tua',
                    'Si iniquitates', 'Dicit Dominus', 'Dicit Dominus',)

EPIPHANY_MASSES = ('', )
